# chrislab

An advanced tool for doing experimental study

## Installation

```bash
pip install chrislab
```

```bash
git clone https://github.com/chrisjihee/chrislab
cd chrislab
pip install .
```

## Reference

- https://pypi.org/project/chrislab/
- https://github.com/chrisjihee/chrislab/
